from scipy import stats as _stats

try:
    from scipy.stats._distn_infrastructure import rv_frozen as rvf
except ImportError:
    from scipy.stats._distn_infrastructure import rv_continuous_frozen as rvf


class _frozen(rvf):
    def __init__(self, dist, *args, **kwds):
        super(_frozen, self).__init__(dist, *args, **kwds)


def buniform(a=0, b=1):
    """
    A uniform continuous random variable.

    Without arguments, the distribution is uniform on [0, 1]. Use the parameters
    `a` and `b` to obtain a uniform distribution on [a, b]. The returned object
    has the same generic methods as other scipy.stats distributions.
    """
    dist = _stats.uniform
    dist.name = 'uniform'
    return _frozen(dist, loc=a, scale=b - a)



from setuptools import setup, find_packages
from os import path

# Get the long description from the README file
here = path.abspath(path.dirname(__file__))
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='better_uniform',
    version='1.0.7',
    url='https://github.com/j-faria/better_uniform.git',
    author='João Faria',
    author_email='joao.faria@astro.up.pt',
    description='A better scipy.stats.uniform',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    install_requires=['scipy'],
)
